@@ -34,6 +34,8 @@
 #include <wordexp.h>
 #include <DConfig>
 
+using namespace Qt::Literals::StringLiterals;
+
 static inline void appendEnvs(const QVariant &var, QStringList &envs)
 {
     if (var.canConvert<QStringList>()) {
@@ -188,7 +190,6 @@ ApplicationService::ApplicationService(DesktopFile source,
 ApplicationService::~ApplicationService()
 {
     detachAllInstance();
-    autoRemoveFromDesktop();
 }
 
 QSharedPointer<ApplicationService> ApplicationService::createApplicationService(
@@ -421,7 +422,7 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
             }
 
             newCommands.push_front(QString{"--SourcePath=%1"}.arg(m_desktopSource.sourcePath()));
-            newCommands.push_front(QString{R"(--unitName=DDE-%1@%2.service)"}.arg(this->id(), instanceRandomUUID));
+            newCommands.push_front(QString{R"(--unitName=app-DDE-%1@%2.service)"}.arg(escapeApplicationId(this->id()), instanceRandomUUID));
 
             QProcess process;
             qDebug().noquote() << "launcher :" << m_launcher << "run with commands:" << newCommands;
@@ -771,10 +772,6 @@ bool ApplicationService::isAutoStart() const noexcept
         return false;
     }
 
-    if (m_autostartSource.m_filePath == m_desktopSource.sourcePath()) {
-        return true;
-    }
-
     auto appId = id();
     auto dirs = getAutoStartDirs();
     QString destDesktopFile;
@@ -1253,6 +1250,10 @@ void ApplicationService::unescapeEens(QVariantMap &options) noexcept
     QStringList result;
     auto envs = options["env"];
     for (const QString &var : envs.toStringList()) {
+        if (var.startsWith(u"DSG_APP_ID="_s)) {
+            result << var;
+            continue;
+        }
         wordexp_t p;
         if (wordexp(var.toStdString().c_str(), &p, 0) == 0) {
             for (size_t i = 0; i < p.we_wordc; i++) {
@@ -1267,28 +1268,6 @@ void ApplicationService::unescapeEens(QVariantMap &options) noexcept
     options.insert("env", result);
 }
 
-void ApplicationService::autoRemoveFromDesktop() const noexcept
-{
-    auto dir = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
-    if (dir.isEmpty()) {
-        return;
-    }
-
-    QFileInfo desktopFile{QDir{dir}.filePath(m_desktopSource.desktopId() + ".desktop")};
-
-    if (!desktopFile.isSymbolicLink()) {
-        qDebug() << desktopFile.filePath() << " is not symbolicLink";
-        return;
-    }
-
-    QFile file{desktopFile.filePath()};
-    auto success = file.remove();
-    if (!success) {
-        qWarning() << "remove desktop file failed:" << file.errorString();
-        return;
-    }
-}
-
 QVariant ApplicationService::findEntryValue(const QString &group,
                                             const QString &valueKey,
                                             EntryValueType type,
